Package 'gpt4r'

Title: ChatGPT templates for use in R and via mygpt in RStudio.
Description: Tools to use ChatGPT via YAML templates Typically used with mygpt to create customized RStudio Addins User can experiment with Chat-GPT inclusion by adapting YAML templates. By default ChatGPT usage will be logged in a local folder. Originally inspired by https://github.com/jcrodriguez1989/chatgpt
Authors: Sebastian Kranz
Maintainer: Sebastian Kranz <[email protected]>
License: GPL >= 3.0
Version: 0.1.0
Built: 2026-05-16 05:25:03 UTC
Source: https://github.com/skranz/gpt4r

Help Index